@@ -21,9 +21,9 @@ class Experiment:
         :param device_serial: board serial number or "auto" to auto-connect
         """
         assert " " not in name
-        self.directory = name
-        if not os.path.exists(self.directory):
-            os.mkdir(self.directory)
+        self.name = name
+        if not os.path.exists(self.name):
+            os.mkdir(self.name)
         if connect:
             self.dev = self.connect_device(device_serial=device_serial)
         else:
